package com.jz.dmp.modules.controller.dataOperation;

import com.jz.common.constant.JsonResult;
import com.jz.common.constant.ResultCode;
import com.jz.common.page.PageInfoResponse;
import com.jz.dmp.modules.controller.dataOperation.bean.*;
import com.jz.dmp.modules.service.DmpDevelopTaskService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 数据运维-数据开发实例
 *
 * @author Bellamy
 * @since 2021-01-13 10:56:18
 */
@RestController
@RequestMapping("/dataDevExamples")
@Api(tags = "数据运维-数据开发实例")
public class DmpDevExamplesController {

    @Autowired
    private DmpDevelopTaskService dmpDevelopTaskService;

    /**
     * 列表分页查询
     *
     * @return
     * @author Bellamy
     * @since 2021-01-14
     */
    @ApiOperation(value = "列表分页查询", notes = "列表分页查询")
    @PostMapping(value = "/listPage")
    public PageInfoResponse<DataDevExamplesListDto> getDevExamplesListPage(@RequestBody @Validated DataDevExamplesListReq req, HttpServletRequest httpRequest) throws Exception {
        PageInfoResponse<DataDevExamplesListDto> pageInfo = new PageInfoResponse<DataDevExamplesListDto>();
        if (StringUtils.isEmpty(req.getProjectId())) {
            pageInfo.setMessage("项目id不能为空！");
            pageInfo.setCode(ResultCode.PARAMS_ERROR);
            return pageInfo;
        }
        try {
            pageInfo = dmpDevelopTaskService.queryDevExamplesListPage(req);
        } catch (Exception e) {
            pageInfo.setMessage("查询失败");
            pageInfo.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            e.printStackTrace();
        }
        return pageInfo;
    }

    /**
     * 获取执行实例的日志详情
     *
     * @return
     * @author Bellamy
     * @since 2021-02-03
     */
    @ApiOperation(value = "执行实例日志详情", notes = "执行实例日志详情")
    @GetMapping(value = "/log")
    @ApiImplicitParams({@ApiImplicitParam(name = "execId", value = "执行实例ID", required = true),
            @ApiImplicitParam(name = "projectId", value = "projectId", required = true)})
    public JsonResult getExamplesLog(@RequestParam String execId,@RequestParam String projectId) {
        if (StringUtils.isEmpty(execId)) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "执行实例ID不能为空！");
        }
        if (StringUtils.isEmpty(projectId)) {
            return JsonResult.error(ResultCode.PARAMS_ERROR, "projectId不能为空！");
        }
        JsonResult result = new JsonResult();
        try {
            result = dmpDevelopTaskService.queryExamplesLogByExecId(execId,projectId);
        } catch (Exception e) {
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage("查询失败！");
            e.printStackTrace();
        }
        return result;
    }

    /**
     * 设置SLA
     *
     * @return
     * @author Bellamy
     * @since 2021-02-03
     */
    @ApiOperation(value = "设置SLA", notes = "设置SLA")
    @PostMapping(value = "/setSla")
    public JsonResult setSla(@RequestBody SetSlaReq req) {
        JsonResult result = new JsonResult();
        try {
            result = dmpDevelopTaskService.setSla(req);
        } catch (Exception e) {
            result.setCode(ResultCode.INTERNAL_SERVER_ERROR);
            result.setMessage(e.getMessage());
            e.printStackTrace();
        }
        return result;
    }

}
